<?php

namespace Drupal\drd;

use Drupal\drd\Entity\DrdDomain;
use GuzzleHttp\Client;
use Psr\Http\Message\ResponseInterface;

/**
 * Class DrdHttpRequest.
 *
 * @package Drupal\drd
 */
class DrdHttpRequest {

  public static function getVersion() {
    $modules = system_rebuild_module_data();
    $version = $modules['drd']->info['version'];
    return empty($version) ? '8.x-3.x' : $version;
  }

  /**
   * @var DrdDomain
   */
  protected $domain;

  /**
   * @var string
   */
  protected $query = '';

  /**
   * @var array
   */
  protected $options = [];

  /**
   * @var ResponseInterface
   */
  protected $response;

  /**
   * @param DrdDomain $domain
   * @return $this
   */
  public function setDomain($domain) {
    $this->domain = $domain;
    return $this;
  }

  /**
   * @param string $query
   * @return $this
   */
  public function setQuery($query) {
    $this->query = $query;
    return $this;
  }

  /**
   * @param string $key
   * @param string $value
   * @return $this
   */
  public function setOption($key, $value) {
    $this->options[$key] = $value;
    return $this;
  }

  /**
   * @return string
   */
  public function getResponse() {
    return base64_decode($this->response->getBody()->getContents());
  }

  /**
   * @return bool
   */
  public function request() {
    $url = $this->domain->buildUrl($this->query);
    $this->options['headers'] = $this->domain->getHeader();
    $this->options['headers']['X-Drd-Version'] = self::getVersion();
    try {
      $client = new Client(['base_uri' => $url->toUriString()]);
      $this->response = $client->request('get', NULL, $this->options);
    }
    catch (\Exception $ex) {
      return FALSE;
    }
    return ($this->response->getStatusCode() == 200 && $this->response->getHeaderLine('content-type') == 'text/plain; charset=utf-8') ? $this : FALSE;
  }

}
